# Changes to CSS Blank Pseudo

### 7.0.1

_October 23, 2024_

- Updated: `postcss-selector-parser`

[Full CHANGELOG](https://github.com/csstools/postcss-plugins/tree/main/plugins/css-blank-pseudo/CHANGELOG.md)
